# Banyan

Banyan Python is an extension to the Python programming language that seamlessly
scales existing libraries and code to massive data and parallel cloud computing.

## Getting Started

Ensure you have Python>=3.8 installed. Install Banyan for Python as follows:

`pip install banyan-python`

Import and configure as follows:

```
import banyan as bn

bn.configure()
```

Visit [Banyan Computing](https://www.banyancomputing.com/resources/) for full documentation.
